{% extends "registration/password_reset_form.html" %}
{% load static %}

{% block extrastyle %}{{ block.super }}
<link rel="stylesheet" href="{% static "admin/css/admin-index.css" %}">{% endblock %}

{% block nav-global %}{{ block.super }}
{% include "django_admin_index/includes/app_list.html" %}
{% endblock nav-global %}
